@@ -17,7 +17,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
  
-#include <gnome.h>
+#include <string.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include "netstat.h"
 #include "utils.h"
 
@@ -114,10 +116,14 @@ netstat_get_active_option (Netinfo * netinfo)
 		} else {
 			option = g_strdup ("-rn -A inet");
 		}
+
+		if (netinfo->stbar_text)
+			g_free (netinfo->stbar_text);
+		netinfo->stbar_text = g_strdup (_("Getting routing table"));
 	}
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (netinfo->protocol))) {
 		/* Only works for Solaris */
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	    	option = g_strdup ("-a -f inet -ln");
 #else
 		if (netinfo_is_ipv6_enable ()) {
@@ -125,11 +131,19 @@ netstat_get_active_option (Netinfo * netinfo)
 		} else {
 			option = g_strdup ("-A inet -ln");
 		}
+
+		if (netinfo->stbar_text)
+			g_free (netinfo->stbar_text);
+		netinfo->stbar_text = g_strdup (_("Getting active Internet connections"));
 #endif
 	}
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (netinfo->multicast))) {
 		/* It works for Solaris and Linux */
 		option = g_strdup ("-g");
+
+		if (netinfo->stbar_text)
+			g_free (netinfo->stbar_text);
+		netinfo->stbar_text = g_strdup (_("Getting group memberships"));
 	}
 	return option;
 }
@@ -182,10 +196,10 @@ netstat_do (Netinfo * netinfo)
 
 /* Process each line from netstat command */
 void 
-netstat_foreach (Netinfo * netinfo, gchar * line, gint len, gpointer user_data)
+netstat_foreach (Netinfo * netinfo, gchar * line, gsize len, gpointer user_data)
 {
 	gchar *text_utf8;
-	gssize bytes_written;
+	gsize bytes_written;
 	GtkTextBuffer *buffer = NULL;
 	GtkTextIter iter;
 	
@@ -278,7 +292,7 @@ netstat_protocol_tree_insert (GtkTreeView *widget, gchar *line)
 	g_return_if_fail (line != NULL);
 
 	count = strip_protocol_line (line, &data);
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	if (count == 5 || count == 6 || count == 9 || count == 10) {
 #else
 	if (count == 5 || count == 6) {
@@ -346,7 +360,7 @@ static gint
 strip_protocol_line (gchar * line, netstat_protocol_data *data)
 {
 	gint count = 0;
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	gint a1, a2, a3, a4;
 	gchar s9[30];
 #else
@@ -357,7 +371,7 @@ strip_protocol_line (gchar * line, netstat_protocol_data *data)
 
 	/*line = g_strdelimit (line, ":", ' ');*/
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	line = g_strdelimit (line, ":", ' ');
 	
 	count = sscanf (line, NETSTAT_PROTOCOL_FORMAT,
@@ -471,7 +485,7 @@ netstat_route_tree_insert (GtkTreeView *widget, gchar *line)
 	g_return_if_fail (line != NULL);
 
 	count = strip_route_line (line, &data);
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	if (count == 6) {
 #else
 	if ((count == 8) || (count == 7)) {
@@ -518,6 +532,7 @@ netstat_route_tree_insert (GtkTreeView *widget, gchar *line)
 							 (model),
 							 &iter,
 							 &sibling);
+			gtk_tree_path_free (path);
 		} else {
 			gtk_list_store_append (GTK_LIST_STORE
 						   (model), &iter);
@@ -547,7 +562,7 @@ strip_route_line (gchar * line, netstat_route_data *data)
 	gchar **items;
 #endif
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	count = sscanf (line, NETSTAT_ROUTE_FORMAT,
 			data->destination,
 			data->gateway, flags,
@@ -590,7 +605,7 @@ netstat_create_route_model (GtkTreeView *widget)
 	renderer = gtk_cell_renderer_text_new ();
 	column =
 	    gtk_tree_view_column_new_with_attributes
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	    (_("Destination/Prefix"), renderer, "text", 0, NULL);
 #else
 	    (_("Destination"), renderer, "text", 0, NULL);
@@ -604,7 +619,7 @@ netstat_create_route_model (GtkTreeView *widget)
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (widget, column);
 
-#ifndef __FreeBSD__
+#if ! (defined(__FreeBSD__) || defined(__OpenBSD__))
 	renderer = gtk_cell_renderer_text_new ();
 	column =
 	    gtk_tree_view_column_new_with_attributes
@@ -679,6 +694,7 @@ netstat_multicast_tree_insert (GtkTreeView *widget, gchar *line)
 							 (model),
 							 &iter,
 							 &sibling);
+			gtk_tree_path_free (path);
 		} else {
 			gtk_list_store_append (GTK_LIST_STORE
 						   (model), &iter);
