@@ -30,7 +30,7 @@
 #   define NETSTAT_ROUTE6_FORMAT "%s %s %s %d %d %d %s"
 #   define NETSTAT_MULTICAST_FORMAT "%s %d %s"
 
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__OpenBSD__)
 #   define NETSTAT_PROTOCOL_FORMAT "%s %d %d %d.%d.%d.%d.%s %s %s"
 #   define ALT_NETSTAT_PROTOCOL_FORMAT "%s %d %d *.%s %s %s"
 #   define NETSTAT_ROUTE_FORMAT "%s %s %s %d %d %s"
